import { ReactPortal } from "react";
import * as nbformat from "@jupyterlab/nbformat";
import { INotebookModel } from "@jupyterlab/notebook";
import { NotebookChange } from "@jupyterlab/shared-models";
import { Cell, ICellModel } from "@jupyterlab/cells";
import { Kernel } from "@jupyterlab/services";
import NotebookAdapter from "./NotebookAdapter";
declare type PortalDisplay = {
    portal: ReactPortal;
    pinned: boolean;
};
export interface INotebookState {
    model?: INotebookModel;
    activeCell?: Cell<ICellModel>;
    kernelStatus?: Kernel.Status;
    notebookChange?: NotebookChange;
    portals: ReactPortal[];
    adapter?: NotebookAdapter;
    saveRequest?: Date;
    portal?: PortalDisplay;
}
export declare const notebookInitialState: INotebookState;
export declare const selectNotebook: () => INotebookState;
export declare const selectNotebookModel: () => INotebookModel | undefined;
export declare const selectActiveCell: () => Cell<ICellModel> | undefined;
export declare const selectNotebookPortals: () => ReactPortal[];
export declare const selectSaveRequest: () => Date | undefined;
export declare const selectNotebookPortal: () => PortalDisplay | undefined;
export declare enum ActionType {
    RESET = "notebook/RESET",
    UPDATE = "notebook/UPDATE",
    NOTEBOOK_CHANGE = "notebook/NOTEBOOK_CHANGE",
    MODEL_CHANGE = "notebook/MODEL_CHANGE",
    ACTIVE_CELL_CHANGE = "notebook/ACTIVE_CELL_CHANGE",
    KERNEL_STATUS_CHANGE = "notebook/KERNEL_STATUS_CHANGE",
    RUN = "notebook/RUN",
    RUN_ALL = "notebook/RUN_ALL",
    SAVE = "notebook/SAVE",
    INTERRUPT = "notebook/INTERRUPT",
    INSERT_ABOVE = "notebook/INSERT_ABOVE",
    INSERT_BELOW = "notebook/INSERT_BELOW",
    DELETE = "notebook/DELETE",
    PORTAL = "notebook/PORTAL",
    SET_PORTALS = "notebook/SET_PORTALS",
    CHANGE_CELL_TYPE = "notebook/CHANGE_CELL_TYPE",
    SET_PORTAL = "notebook/SET_PORTAL"
}
export declare const notebookActions: {
    reset: import("typescript-fsa").ActionCreator<void>;
    update: import("typescript-fsa").ActionCreator<Partial<INotebookState>>;
    notebookChange: import("typescript-fsa").ActionCreator<NotebookChange>;
    modelChange: import("typescript-fsa").ActionCreator<INotebookModel>;
    activeCellChange: import("typescript-fsa").ActionCreator<Cell<ICellModel>>;
    kernelStatusChanged: import("typescript-fsa").ActionCreator<Kernel.Status>;
    portal: import("typescript-fsa").ActionCreator<ReactPortal[]>;
    setPortals: import("typescript-fsa").ActionCreator<ReactPortal[]>;
    setPortal: import("typescript-fsa").ActionCreator<PortalDisplay | undefined>;
    save: import("typescript-fsa").AsyncActionCreators<Date | undefined, Date | undefined, {}>;
    run: import("typescript-fsa").AsyncActionCreators<void, void, {}>;
    runAll: import("typescript-fsa").AsyncActionCreators<void, void, {}>;
    interrupt: import("typescript-fsa").AsyncActionCreators<void, void, {}>;
    insertAbove: import("typescript-fsa").AsyncActionCreators<nbformat.CellType, nbformat.CellType, {}>;
    insertBelow: import("typescript-fsa").AsyncActionCreators<nbformat.CellType, nbformat.CellType, {}>;
    delete: import("typescript-fsa").AsyncActionCreators<void, void, {}>;
    changeCellType: import("typescript-fsa").AsyncActionCreators<nbformat.CellType, nbformat.CellType, {}>;
};
export declare const notebookEpics: any;
export declare const notebookReducer: import("typescript-fsa-reducers").ReducerBuilder<INotebookState, INotebookState>;
export {};
