import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useState, useMemo, useEffect } from 'react';
import { useDispatch } from 'react-redux';
import Stack from '@mui/material/Stack';
import LinearProgress from '@mui/material/LinearProgress';
import { OutputAreaModel } from '@jupyterlab/outputarea';
import OutputAdapter from './OutputAdapter';
import { selectExecute, outputActions, outputReducer } from './OutputState';
import { useJupyter } from "./../../jupyter/JupyterContext";
import LuminoAttached from './../../jupyter/lumino/LuminoAttached';
import CodeMirrorEditor from '././../codemirror/CodeMirrorEditor';
import '@lumino/default-theme/style/index.css';
/*
import "@jupyterlab/outputarea/style/index.css";
import '@jupyterlab/json-extension/style/index.css';
import "@jupyterlab/theme-light-extension/style/theme.css";
import "@@jupyter-widgets/base/css/index.css";
import "@jupyter-widgets/controls/css/widgets-base.css";
*/
import './Output.css';
const KernelRunning = () => (_jsx(Stack, Object.assign({ sx: { width: '100%', color: 'grey.500' }, spacing: 2 }, { children: _jsx(LinearProgress, { color: "primary" }, void 0) }), void 0));
export const Output = (props) => {
    const { injectableStore } = useJupyter();
    const { initialOutput, autoRun, code, kernel, showEditor, clearTrigger, executeTrigger, sourceId, receipt, disableRun, insertText, toolbarPosition, codePre } = props;
    const dispatch = useDispatch();
    const [kernelStatus, setKernelStatus] = useState('unknown');
    useMemo(() => {
        injectableStore.inject('outputs', outputReducer);
    }, []);
    const [model] = useState(new OutputAreaModel({
        trusted: true,
        values: initialOutput,
    }));
    const outputAdapter = useMemo(() => {
        if (kernel) {
            const outputAdapter = new OutputAdapter(kernel.getJupyterKernel(), model, {});
            if (receipt) {
                outputAdapter.outputArea.model.changed.connect((sender, change) => {
                    if (change.type === 'add') {
                        change.newValues.map(val => {
                            if (val && val.data) {
                                //              const out = val.data['application/vnd.jupyter.stdout'];
                                const out = val.data['text/html'];
                                if (out) {
                                    if (out.indexOf(receipt) > -1) {
                                        dispatch(outputActions.grade({
                                            sourceId,
                                            success: true,
                                        }));
                                    }
                                }
                            }
                        });
                    }
                });
            }
            return outputAdapter;
        }
    }, [sourceId, kernel]);
    useEffect(() => {
        if (kernel) {
            kernel.getJupyterKernel().then((kernelConnection) => {
                setKernelStatus(kernelConnection.status);
                kernelConnection.statusChanged.connect((kernelConnection, status) => {
                    setKernelStatus(status);
                });
            });
        }
        return () => {
            //      kernel.getJupyterKernel().then(k => k.shutdown().then(() => console.log(`Kernel ${k.clientId} is terminated.`)));
        };
    }, [kernel]);
    const executeRequest = selectExecute(sourceId);
    useEffect(() => {
        if (executeRequest && outputAdapter) {
            outputAdapter.execute(executeRequest.source);
        }
    }, [executeRequest, outputAdapter]);
    useEffect(() => {
        if (autoRun && outputAdapter) {
            outputAdapter.execute(code);
        }
    }, [executeTrigger, outputAdapter]);
    useEffect(() => {
        if (showEditor && outputAdapter) {
            outputAdapter.clearOutput();
        }
    }, [clearTrigger, outputAdapter]);
    return (_jsxs(_Fragment, { children: [showEditor && outputAdapter &&
                _jsx("div", Object.assign({ css: {
                        '& .cm-editor': {
                            borderRadius: '5px',
                        },
                    } }, { children: _jsx(CodeMirrorEditor, { autoRun: autoRun, code: code, codePre: codePre, kernel: kernel, outputAdapter: outputAdapter, sourceId: sourceId, disableRun: disableRun, insertText: insertText, toolbarPosition: toolbarPosition }, void 0) }), void 0),
            (kernelStatus !== 'idle') && _jsx(KernelRunning, {}, void 0),
            outputAdapter &&
                _jsx("div", Object.assign({ css: {
                        '& .jp-OutputPrompt': {
                            display: 'none',
                        },
                        '& .jp-OutputArea': {
                            fontSize: '10px',
                        },
                        '& pre': {
                            fontSize: '12px',
                            wordBreak: 'break-all',
                            wordWrap: 'break-word',
                            whiteSpace: 'pre-wrap',
                        },
                    } }, { children: _jsx(LuminoAttached, { children: outputAdapter.panel }, void 0) }), void 0)] }, void 0));
};
Output.defaultProps = {
    initialOutput: [
        {
            "output_type": "execute_result",
            "data": {
                "text/html": [
                    "<h3>I am the default output...  👉  Run the snippet to update me...  👀</h3>"
                ]
            },
            "execution_count": 0,
            "metadata": {},
        }
    ],
    disableRun: false,
    toolbarPosition: 'up',
    executeTrigger: 0,
    clearTrigger: 0,
};
export default Output;
//# sourceMappingURL=Output.js.map