import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useEffect, useState, useMemo } from 'react';
import { useTheme, ActionMenu, ActionList, IconButton, Box } from '@primer/react';
import { KebabHorizontalIcon, ArrowRightIcon, StopIcon, PaintbrushIcon } from '@primer/octicons-react';
const OutputToolbarMenu = (props) => {
    const { executeCode, outputAdapter, editorView } = props;
    return (_jsxs(ActionMenu, { children: [_jsx(ActionMenu.Anchor, { children: _jsx(IconButton, { icon: KebabHorizontalIcon, variant: "invisible" }, void 0) }, void 0),
            _jsx(ActionMenu.Overlay, { children: _jsxs(ActionList, { children: [_jsxs(ActionList.Item, Object.assign({ onSelect: e => { e.preventDefault(); executeCode(editorView); } }, { children: [_jsx(ActionList.LeadingVisual, { children: _jsx(ArrowRightIcon, {}, void 0) }, void 0),
                                _jsx(ActionList.TrailingVisual, { children: "\u21E7 \u21B5" }, void 0), "Run code"] }), void 0),
                        _jsxs(ActionList.Item, Object.assign({ onSelect: e => { e.preventDefault(); outputAdapter.interrupt(); } }, { children: [_jsx(ActionList.LeadingVisual, { children: _jsx(StopIcon, {}, void 0) }, void 0), "Interrupt kernel"] }), void 0),
                        _jsxs(ActionList.Item, Object.assign({ variant: "danger", onClick: e => { e.preventDefault(); outputAdapter.clearOutput(); } }, { children: [_jsx(ActionList.LeadingVisual, { children: _jsx(PaintbrushIcon, {}, void 0) }, void 0), "Clear outputs"] }), void 0)] }, void 0) }, void 0)] }, void 0));
};
const KernelStatus = ({ color }) => (_jsx(Box, { sx: { backgroundColor: color, width: '14px', height: '14px', borderRadius: 3 } }, void 0));
export const OutputToolbar = (props) => {
    const { executeCode, editorView, kernel, codePre } = props;
    const { theme } = useTheme();
    const okColor = useMemo(() => theme === null || theme === void 0 ? void 0 : theme.colorSchemes.light.colors.success.muted, []);
    const nokColor = useMemo(() => theme === null || theme === void 0 ? void 0 : theme.colorSchemes.light.colors.severe.muted, []);
    const [kernelStatus, setKernelStatus] = useState('unknown');
    useEffect(() => {
        kernel.getJupyterKernel().then((kernelConnection) => {
            if (codePre) {
                executeCode(editorView, codePre);
            }
            setKernelStatus(kernelConnection.status);
            kernelConnection.statusChanged.connect((kernelConnection, status) => {
                setKernelStatus(status);
            });
        });
    }, []);
    const getKernelStatusColor = (status) => {
        if (status === "idle") {
            return okColor;
        }
        return nokColor;
    };
    return (_jsxs(Box, Object.assign({ display: "flex" }, { children: [_jsx(Box, { flexGrow: 1 }, void 0),
            _jsx(Box, Object.assign({ sx: { paddingTop: '6px' } }, { children: _jsx(KernelStatus, { color: getKernelStatusColor(kernelStatus) }, void 0) }), void 0),
            _jsx(Box, { children: _jsx(OutputToolbarMenu, Object.assign({}, props), void 0) }, void 0)] }), void 0));
};
export default OutputToolbar;
//# sourceMappingURL=OutputToolbar.js.map