import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { ThemeProvider, BaseStyles } from "@primer/react";
import { ErrorBoundary } from 'react-error-boundary';
import { JupyterContextProvider } from './JupyterContext';
import { getJupyterServerHttpUrl, getJupyterServerWsUrl, loadJupyterConfig } from './JupyterConfig';
import injectableStore from '../state/Store';
/**
 * The component to be used as fallback in case of error.
 */
const ErrorFallback = ({ error, resetErrorBoundary }) => {
    return (_jsxs("div", Object.assign({ role: "alert" }, { children: [_jsx("p", { children: "Oops, something went wrong." }, void 0),
            _jsx("pre", { children: error.message }, void 0)] }), void 0));
};
/**
 * The Jupyter context. This handles the needed initialization
 * and ensure the Redux and the Material UI theme providers
 * are available.
 */
export const Jupyter = (props) => {
    const { lite, createKernel } = props;
    loadJupyterConfig(props);
    return (_jsx(ErrorBoundary, Object.assign({ FallbackComponent: ErrorFallback }, { children: _jsx(ThemeProvider, Object.assign({ colorMode: "day" }, { children: _jsx(BaseStyles, { children: _jsx(JupyterContextProvider, Object.assign({ lite: lite, createKernel: createKernel, baseUrl: getJupyterServerHttpUrl(), wsUrl: getJupyterServerWsUrl(), injectableStore: props.injectableStore || injectableStore, variant: "default" }, { children: props.children }), void 0) }, void 0) }), void 0) }), void 0));
};
Jupyter.defaultProps = {
    lite: false,
    createKernel: false,
    collaborative: false,
    terminals: false,
};
export default Jupyter;
//# sourceMappingURL=Jupyter.js.map